==> marketplace-constants-0.1.4.9.tar.gz: marketplace-constants-0.1.4.9/mpconstants/regions/fy_NL.py <==
REGIONS = {u'ad': u'Andorra',
 u'ae': u'Ferienigde Arabiske Emiraten',
 u'af': u'Afganistan',
 u'ag': u'Antigua en Barbuda',
 u'ai': u'Anguilla',
 u'al': u'Albaanje',
 u'am': u'Armeenje',
 u'an': u'Nederl\\u00E2nske Antillen',
 u'ao': u'Angola',
 u'aq': u'Antarktika',
 u'ar': u'Argentinje',
 u'as': u'Amerikaansk Samoa',
 u'at': u'Eastenryk',
 u'au': u'Austraalje',
 u'aw': u'Aruba',
 u'ax': u'\\u00C5land Eilannen',
 u'az': u'Azerbeijaan',
 u'ba': u'Bosnje en Herzgovina',
 u'bb': u'Barbados',
 u'bd': u'Bangladesh',
 u'be': u'Belgje',
 u'bf': u'Burkina Faso',
 u'bg': u'Bulgarije',
 u'bh': u'Bahrein',
 u'bi': u'Burundi',
 u'bj': u'Benin',
 u'bl': u'Sint Bartholemeus',
 u'bm': u'Bermuda',
 u'bn': u'Brunei',
 u'bo': u'Bolivja',
 u'br': u'Brazili\\u00EB',
 u'bs': u'Bahamas',
 u'bt': u'Bhutan',
 u'bv': u'Bouvet Eil\\u00E2n',
 u'bw': u'Botswana',
 u'by': u'Belarus',
 u'bz': u'Belize',
 u'ca': u'Kanada',
 u'cc': u'Kokos (Keeling) Eilannen',
 u'cd': u'Kongo-Kinshasa',
 u'cf': u'Sintraal Afrikaanske Republiek',
 u'cg': u'Kongo-Brazzaville',
 u'ch': u'Switserl\\u00E2n',
 u'ci': u'Ivoarkust',
 u'ck': u'Cook Eilannen',
 u'cl': u'Sili',
 u'cm': u'Kameroen',
 u'cn': u'Sina',
 u'co': u'Kolombia',
 u'cr': u'Kosta Rika',
 u'cu': u'Kuba',
 u'cv': u'Kap Verde',
 u'cx': u'Krist Eil\\u00E2n',
 u'cy': u'Syprus',
 u'cz': u'Tsjechyske Republiek',
 u'de': u'D\\u00FBtsl\\u00E2n',
 u'dj': u'Djibouti',
 u'dk': u'Denemarken',
 u'dm': u'Dominica',
 u'do': u'Dominikaanske Republiek',
 u'dz': u'Algerije',
 u'ec': u'Ekwador',
 u'ee': u'Estoonje',
 u'eg': u'Egypte',
 u'eh': u'Wester Sahara',
 u'er': u'Eritrea',
 u'es': u'Spanje',
 u'et': u'Ethioopje',
 u'fi': u'Finl\\u00E2n',
 u'fj': u'Fidzji',
 u'fk': u'Falkl\\u00E2n Eilannen (Malvinas)',
 u'fm': u'Mikroneesje',
 u'fo': u'Faroe Eilannen',
 u'fr': u'Frankryk',
 u'ga': u'Gabon',
 u'gb': u'Ferienigd Keninkryk',
 u'gd': u'Grenada',
 u'ge': u'Georgia',
 u'gf': u'Fr\\u00E2nsk Guyana',
 u'gg': u'Guernsey',
 u'gh': u'Ghana',
 u'gi': u'Gibraltar',
 u'gl': u'Grienl\\u00E2n',
 u'gm': u'Gambia',
 u'gn': u'Guinea',
 u'gp': u'Guadeloupe',
 u'gq': u'Ekwatorial Guinea',
 u'gr': u'Grykel\\u00E2n',
 u'gs': u'S\\u00FAd Georgia en de S\\u00FAd Sandwich Eilannen',
 u'gt': u'Guatemala',
 u'gu': u'Guam',
 u'gw': u'Guinea-Bissau',
 u'gy': u'Guyana',
 u'hk': u'Hong Kong',
 u'hm': u'Heard Eil\\u00E2n en McDonald Eilannen',
 u'hn': u'Honduras',
 u'hr': u'Kroaasje',
 u'ht': u'Haiti',
 u'hu': u'Hungarije',
 u'id': u'Indoneesje',
 u'ie': u'Ierl\\u00E2n',
 u'il': u'Israel',
 u'im': u'Eial\\u00E2n fan Man',
 u'in': u'India',
 u'io': u'Brits Indyske Oseaan Territorium',
 u'iq': u'Irak',
 u'ir': u'Iran',
 u'is': u'Iisl\\u00E2n',
 u'it': u'Itaalje',
 u'je': u'Jersey',
 u'jm': u'Jamaika',
 u'jo': u'Jordaanje',
 u'jp': u'Japan',
 u'ke': u'Kenya',
 u'kg': u'Kyrgyzstan',
 u'kh': u'Kambodjaa',
 u'ki': u'Kiribati',
 u'km': u'Komoros',
 u'kn': u'Sint Kitts en Nevis',
 u'kp': u'Noard-Korea',
 u'kr': u'S\\u00FAd-Korea',
 u'kw': u'Koeweit',
 u'ky': u'Kaaiman Eilannen',
 u'kz': u'Kazachstan',
 u'la': u'Laos',
 u'lb': u'Libanon',
 u'lc': u'Sint Lucia',
 u'li': u'Liechtenstein',
 u'lk': u'Sri Lanka',
 u'lr': u'Liberia',
 u'ls': u'Lesotho',
 u'lt': u'Lithuaanje',
 u'lu': u'Luksemburg',
 u'lv': u'Latvia',
 u'ly': u'Libi\\u00EB',
 u'ma': u'Marokko',
 u'mc': u'Monako',
 u'md': u'Republiek fan Moldaavje',
 u'me': u'Montenegro',
 u'mf': u'Sint Martin',
 u'mg': u'Madagaskar',
 u'mh': u'Marshall Eilannen',
 u'mk': u'Masedoonje, V.J.R.',
 u'ml': u'Mali',
 u'mm': u'Myanmar',
 u'mn': u'Mongoolje',
 u'mo': u'Makao',
 u'mp': u'Noarske Mariana Eilannen',
 u'mq': u'Martiniek',
 u'mr': u'Mauritaanje',
 u'ms': u'Montserrat',
 u'mt': u'Malta',
 u'mu': u'Mauritius',
 u'mv': u'Malediven',
 u'mw': u'Malawi',
 u'mx': u'Meksiko',
 u'my': u'Maleisje',
 u'mz': u'Mozambiek',
 u'na': u'Namibi\\u00EB',
 u'nc': u'Nij Kaledoonje',
 u'ne': u'Nigeria',
 u'nf': u'Norfolk Eil\\u00E2n',
 u'ng': u'Nigeria',
 u'ni': u'Nikaragua',
 u'nl': u'Nederl\\u00E2n',
 u'no': u'Norway',
 u'np': u'Nepal',
 u'nr': u'Nauru',
 u'nu': u'Niue',
 u'nz': u'Nij-Seel\\u00E2n',
 u'om': u'Oman',
 u'pa': u'Panama',
 u'pe': u'Peru',
 u'pf': u'Fr\\u00E2nsk Polyneesje',
 u'pg': u'Papua Nij Gunea',
 u'ph': u'Filippijnen',
 u'pk': u'Pakistan',
 u'pl': u'Poalen',
 u'pm': u'Saint Pierre and Miquelon',
 u'pn': u'Pitcairn',
 u'pr': u'Puerto Riko',
 u'ps': u'Occupied Palestinian Territory',
 u'pt': u'Portugal',
 u'pw': u'Palau',
 u'py': u'Paraguay',
 u'qa': u'Katar',
 u're': u'Reunion',
 u'ro': u'Roemeenje',
 u'rs': u'Servje',
 u'ru': u'Rusl\\u00E2n',
 u'rw': u'Rwanda',
 u'sa': u'Saudi-Arabi\\u00EB',
 u'sb': u'Solomon Islands',
 u'sc': u'Seysjellen',
 u'sd': u'Sudan',
 u'se': u'Sweden',
 u'sg': u'Singapore',
 u'sh': u'Sint Helena',
 u'si': u'Sloveenje',
 u'sj': u'Svalbard en Jan Mayen',
 u'sk': u'Slowakije',
 u'sl': u'Sierra Leone',
 u'sm': u'San Marino',
 u'sn': u'Senegal',
 u'so': u'Somaalje',
 u'sr': u'Suriname',
 u'st': u'Sao Tome en Prinsipe',
 u'sv': u'El Salvador',
 u'sy': u'Syri\\u00EB',
 u'sz': u'Swazil\\u00E2n',
 u'tc': u'Turks en Kaikos Eilannen',
 u'td': u'Chad',
 u'tf': u'Fr\\u00E2nsk S\\u00FAdlike Territoria',
 u'tg': u'Togo',
 u'th': u'Thail\\u00E2n',
 u'tj': u'Tajikistan',
 u'tk': u'Tokelau',
 u'tl': u'Timor-Leste',
 u'tm': u'Turkmenistan',
 u'tn': u'Tunesi\\u00EB',
 u'to': u'Tonga',
 u'tr': u'Turkey',
 u'tt': u'Trinidad en Tobago',
 u'tv': u'Tuvalu',
 u'tw': u'Taiwan',
 u'tz': u'Tanzania',
 u'ua': u'Ukraine',
 u'ug': u'Uganda',
 u'um': u'Ferienigde Steaten lytse eilannen',
 u'us': u'Ferienigde Steaten',
 u'uy': u'Uruguay',
 u'uz': u'Uzbekistan',
 u'va': u'Vatican City',
 u'vc': u'Saint Vincent and the Grenadines',
 u've': u'Venezuela',
 u'vg': u'Britske Virgin Eilannen',
 u'vi': u'F.S. Virgin Eilannen',
 u'vn': u'Vietnam',
 u'vu': u'Vanuatu',
 u'wf': u'Wallis and Futuna',
 u'ws': u'Samoa',
 u'ye': u'Jemen',
 u'yt': u'Mayotte',
 u'za': u'Zuid-Afrika',
 u'zm': u'Zambia',
 u'zw': u'Zimbabwe'}

==> marketplace-constants-0.2.0.tar.gz: marketplace-constants-0.2.0/mpconstants/regions/fy_NL.py <==
REGIONS = {u'ad': u'Andorra',
 u'ae': u'Ferienigde Arabiske Emiraten',
 u'af': u'Afganistan',
 u'ag': u'Antigua en Barbuda',
 u'ai': u'Anguilla',
 u'al': u'Albaanje',
 u'am': u'Armeenje',
 u'an': u'Nederl\xe2nske Antillen',
 u'ao': u'Angola',
 u'aq': u'Antarktika',
 u'ar': u'Argentinje',
 u'as': u'Amerikaansk Samoa',
 u'at': u'Eastenryk',
 u'au': u'Austraalje',
 u'aw': u'Aruba',
 u'ax': u'\xc5land Eilannen',
 u'az': u'Azerbeijaan',
 u'ba': u'Bosnje en Herzgovina',
 u'bb': u'Barbados',
 u'bd': u'Bangladesh',
 u'be': u'Belgje',
 u'bf': u'Burkina Faso',
 u'bg': u'Bulgarije',
 u'bh': u'Bahrein',
 u'bi': u'Burundi',
 u'bj': u'Benin',
 u'bl': u'Sint Bartholemeus',
 u'bm': u'Bermuda',
 u'bn': u'Brunei',
 u'bo': u'Bolivja',
 u'br': u'Brazili\xeb',
 u'bs': u'Bahamas',
 u'bt': u'Bhutan',
 u'bv': u'Bouvet Eil\xe2n',
 u'bw': u'Botswana',
 u'by': u'Belarus',
 u'bz': u'Belize',
 u'ca': u'Kanada',
 u'cc': u'Kokos (Keeling) Eilannen',
 u'cd': u'Kongo-Kinshasa',
 u'cf': u'Sintraal Afrikaanske Republiek',
 u'cg': u'Kongo-Brazzaville',
 u'ch': u'Switserl\xe2n',
 u'ci': u'Ivoarkust',
 u'ck': u'Cook Eilannen',
 u'cl': u'Sili',
 u'cm': u'Kameroen',
 u'cn': u'Sina',
 u'co': u'Kolombia',
 u'cr': u'Kosta Rika',
 u'cu': u'Kuba',
 u'cv': u'Kap Verde',
 u'cx': u'Krist Eil\xe2n',
 u'cy': u'Syprus',
 u'cz': u'Tsjechyske Republiek',
 u'de': u'D\xfbtsl\xe2n',
 u'dj': u'Djibouti',
 u'dk': u'Denemarken',
 u'dm': u'Dominica',
 u'do': u'Dominikaanske Republiek',
 u'dz': u'Algerije',
 u'ec': u'Ekwador',
 u'ee': u'Estoonje',
 u'eg': u'Egypte',
 u'eh': u'Wester Sahara',
 u'er': u'Eritrea',
 u'es': u'Spanje',
 u'et': u'Ethioopje',
 u'fi': u'Finl\xe2n',
 u'fj': u'Fidzji',
 u'fk': u'Falkl\xe2n Eilannen (Malvinas)',
 u'fm': u'Mikroneesje',
 u'fo': u'Faroe Eilannen',
 u'fr': u'Frankryk',
 u'ga': u'Gabon',
 u'gb': u'Ferienigd Keninkryk',
 u'gd': u'Grenada',
 u'ge': u'Georgia',
 u'gf': u'Fr\xe2nsk Guyana',
 u'gg': u'Guernsey',
 u'gh': u'Ghana',
 u'gi': u'Gibraltar',
 u'gl': u'Grienl\xe2n',
 u'gm': u'Gambia',
 u'gn': u'Guinea',
 u'gp': u'Guadeloupe',
 u'gq': u'Ekwatorial Guinea',
 u'gr': u'Grykel\xe2n',
 u'gs': u'S\xfad Georgia en de S\xfad Sandwich Eilannen',
 u'gt': u'Guatemala',
 u'gu': u'Guam',
 u'gw': u'Guinea-Bissau',
 u'gy': u'Guyana',
 u'hk': u'Hong Kong',
 u'hm': u'Heard Eil\xe2n en McDonald Eilannen',
 u'hn': u'Honduras',
 u'hr': u'Kroaasje',
 u'ht': u'Haiti',
 u'hu': u'Hungarije',
 u'id': u'Indoneesje',
 u'ie': u'Ierl\xe2n',
 u'il': u'Israel',
 u'im': u'Eial\xe2n fan Man',
 u'in': u'India',
 u'io': u'Brits Indyske Oseaan Territorium',
 u'iq': u'Irak',
 u'ir': u'Iran',
 u'is': u'Iisl\xe2n',
 u'it': u'Itaalje',
 u'je': u'Jersey',
 u'jm': u'Jamaika',
 u'jo': u'Jordaanje',
 u'jp': u'Japan',
 u'ke': u'Kenya',
 u'kg': u'Kyrgyzstan',
 u'kh': u'Kambodjaa',
 u'ki': u'Kiribati',
 u'km': u'Komoros',
 u'kn': u'Sint Kitts en Nevis',
 u'kp': u'Noard-Korea',
 u'kr': u'S\xfad-Korea',
 u'kw': u'Koeweit',
 u'ky': u'Kaaiman Eilannen',
 u'kz': u'Kazachstan',
 u'la': u'Laos',
 u'lb': u'Libanon',
 u'lc': u'Sint Lucia',
 u'li': u'Liechtenstein',
 u'lk': u'Sri Lanka',
 u'lr': u'Liberia',
 u'ls': u'Lesotho',
 u'lt': u'Lithuaanje',
 u'lu': u'Luksemburg',
 u'lv': u'Latvia',
 u'ly': u'Libi\xeb',
 u'ma': u'Marokko',
 u'mc': u'Monako',
 u'md': u'Republiek fan Moldaavje',
 u'me': u'Montenegro',
 u'mf': u'Sint Martin',
 u'mg': u'Madagaskar',
 u'mh': u'Marshall Eilannen',
 u'mk': u'Masedoonje, V.J.R.',
 u'ml': u'Mali',
 u'mm': u'Myanmar',
 u'mn': u'Mongoolje',
 u'mo': u'Makao',
 u'mp': u'Noarske Mariana Eilannen',
 u'mq': u'Martiniek',
 u'mr': u'Mauritaanje',
 u'ms': u'Montserrat',
 u'mt': u'Malta',
 u'mu': u'Mauritius',
 u'mv': u'Malediven',
 u'mw': u'Malawi',
 u'mx': u'Meksiko',
 u'my': u'Maleisje',
 u'mz': u'Mozambiek',
 u'na': u'Namibi\xeb',
 u'nc': u'Nij Kaledoonje',
 u'ne': u'Nigeria',
 u'nf': u'Norfolk Eil\xe2n',
 u'ng': u'Nigeria',
 u'ni': u'Nikaragua',
 u'nl': u'Nederl\xe2n',
 u'no': u'Norway',
 u'np': u'Nepal',
 u'nr': u'Nauru',
 u'nu': u'Niue',
 u'nz': u'Nij-Seel\xe2n',
 u'om': u'Oman',
 u'pa': u'Panama',
 u'pe': u'Peru',
 u'pf': u'Fr\xe2nsk Polyneesje',
 u'pg': u'Papua Nij Gunea',
 u'ph': u'Filippijnen',
 u'pk': u'Pakistan',
 u'pl': u'Poalen',
 u'pm': u'Saint Pierre and Miquelon',
 u'pn': u'Pitcairn',
 u'pr': u'Puerto Riko',
 u'ps': u'Occupied Palestinian Territory',
 u'pt': u'Portugal',
 u'pw': u'Palau',
 u'py': u'Paraguay',
 u'qa': u'Katar',
 u're': u'Reunion',
 u'ro': u'Roemeenje',
 u'rs': u'Servje',
 u'ru': u'Rusl\xe2n',
 u'rw': u'Rwanda',
 u'sa': u'Saudi-Arabi\xeb',
 u'sb': u'Solomon Islands',
 u'sc': u'Seysjellen',
 u'sd': u'Sudan',
 u'se': u'Sweden',
 u'sg': u'Singapore',
 u'sh': u'Sint Helena',
 u'si': u'Sloveenje',
 u'sj': u'Svalbard en Jan Mayen',
 u'sk': u'Slowakije',
 u'sl': u'Sierra Leone',
 u'sm': u'San Marino',
 u'sn': u'Senegal',
 u'so': u'Somaalje',
 u'sr': u'Suriname',
 u'st': u'Sao Tome en Prinsipe',
 u'sv': u'El Salvador',
 u'sy': u'Syri\xeb',
 u'sz': u'Swazil\xe2n',
 u'tc': u'Turks en Kaikos Eilannen',
 u'td': u'Chad',
 u'tf': u'Fr\xe2nsk S\xfadlike Territoria',
 u'tg': u'Togo',
 u'th': u'Thail\xe2n',
 u'tj': u'Tajikistan',
 u'tk': u'Tokelau',
 u'tl': u'Timor-Leste',
 u'tm': u'Turkmenistan',
 u'tn': u'Tunesi\xeb',
 u'to': u'Tonga',
 u'tr': u'Turkey',
 u'tt': u'Trinidad en Tobago',
 u'tv': u'Tuvalu',
 u'tw': u'Taiwan',
 u'tz': u'Tanzania',
 u'ua': u'Ukraine',
 u'ug': u'Uganda',
 u'um': u'Ferienigde Steaten lytse eilannen',
 u'us': u'Ferienigde Steaten',
 u'uy': u'Uruguay',
 u'uz': u'Uzbekistan',
 u'va': u'Vatican City',
 u'vc': u'Saint Vincent and the Grenadines',
 u've': u'Venezuela',
 u'vg': u'Britske Virgin Eilannen',
 u'vi': u'F.S. Virgin Eilannen',
 u'vn': u'Vietnam',
 u'vu': u'Vanuatu',
 u'wf': u'Wallis and Futuna',
 u'ws': u'Samoa',
 u'ye': u'Jemen',
 u'yt': u'Mayotte',
 u'za': u'Zuid-Afrika',
 u'zm': u'Zambia',
 u'zw': u'Zimbabwe'}
